/*
 *  /MathJax-v2/localization/ast/MathMenu.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("ast","MathMenu",{version:"2.7.9",isLoaded:true,strings:{Show:"Ver les f\u00F3rmules como",MathMLcode:"C\u00F3digu MathML",OriginalMathML:"MathML orixinal",TeXCommands:"Comandos de TeX",AsciiMathInput:"Entrada AsciiMathML",Original:"Forma orixinal",ErrorMessage:"Mensaxe d'error",Annotation:"Anotaci\u00F3n",TeX:"TeX",StarMath:"StarMath",Maple:"Maple",ContentMathML:"Conten\u00EDu MathML",OpenMath:"OpenMath",texHints:"Amosar gabitos TeX en MathML",Settings:"Configuraci\u00F3n de matem\u00E1tiques",ZoomTrigger:"Disparador del zoom",Hover:"Al pasar el mur",Click:"Al facer clic",DoubleClick:"Con doble clic",NoZoom:"Ensin zoom",TriggerRequires:"El disparador requier:",Option:"Opci\u00F3n",Alt:"Alt",Command:"Comandu",Control:"Control",Shift:"May\u00FAs",ZoomFactor:"Factor d'ampliaci\u00F3n",Renderer:"Renderizador de matem\u00E1tiques",MPHandles:"Permitir que MathPlayer alministre:",MenuEvents:"Socesos de men\u00FA",MouseEvents:"Socesos del mur",MenuAndMouse:"Socesos del mur y del men\u00FA",FontPrefs:"Preferencies de tipograf\u00EDa",ForHTMLCSS:"Pa HTML-CSS:",Auto:"Auto",TeXLocal:"TeX (llocal)",TeXWeb:"TeX (web)",TeXImage:"TeX (imaxe)",STIXLocal:"STIX (llocal)",STIXWeb:"STIX (web)",AsanaMathWeb:"Asana Math (web)",GyrePagellaWeb:"Gyre Pagella (web)",GyreTermesWeb:"Gyre Termes (web)",LatinModernWeb:"Llat\u00EDn modernu (web)",NeoEulerWeb:"Neo Euler (web)",ContextMenu:"Men\u00FA contestual",Browser:"Navegador",Scale:"Escalar toles f\u00F3rmules...",Discoverable:"Illuminar al pasar el mur",Locale:"Llingua",LoadLocale:"Cargar d'una URL...",About:"Tocante a MathJax",Help:"Ayuda de MathJax",localTeXfonts:"usando tipograf\u00EDa TeX llocal",webTeXfonts:"usando tipograf\u00EDa TeX de la web",imagefonts:"usando tipograf\u00EDa d'imaxe",localSTIXfonts:"usando tipograf\u00EDa STIX llocal",webSVGfonts:"usando tipograf\u00EDa SVG de la web",genericfonts:"usando tipograf\u00EDa Unicode xen\u00E9rica",wofforotffonts:"tipograf\u00EDa WOFF u OTF",eotffonts:"tipograf\u00EDa EOT",svgfonts:"tipograf\u00EDa SVG",WebkitNativeMMLWarning:"Paez que'l so restolador nun tien sofitu pa MathML de mou nativu, de mou que cambiar la salida a MathML pue facer que les f\u00F3rmules de la p\u00E1xina nun puedan lleese",MSIENativeMMLWarning:"Internet Explorer requier el complementu MathPlayer pa procesar la salida de MathML",OperaNativeMMLWarning:"El sofitu d'Opera pa MathML ye parcial, de mou que cambiar la salida a MathML pue facer que delles espresiones nun se vean bien.",SafariNativeMMLWarning:"El MathML nativu del so navegador nun cuenta con toles carauter\u00EDstiques qu'usa MathJax, de mou que delles espresiones podr\u00EDen nun representase correutamente.",FirefoxNativeMMLWarning:"El MathML nativu del so navegador nun cuenta con toles carauter\u00EDstiques qu'usa MathJax, de mou que delles espresiones podr\u00EDen nun representase correutamente.",MSIESVGWarning:"SVG nun ta implement\u00E1u n'Internet Explorer anterior a IE9 o cuando ta emulando IE8 o anterior. Si cambia a la salida SVG, les f\u00F3rmules nun se ver\u00E1n correutamente.",LoadURL:"Cargar los datos de traducci\u00F3n d'esta URL:",BadURL:"La URL tendr\u00EDa de ser pa un ficheru JavaScript que define los datos de traducci\u00F3n de MathJax. Los nomes de los ficheros JavaScript tendr\u00EDen d'acabar en '.js'",BadData:"Nun pudieron cargase los datos de traducci\u00F3n de %1",SwitchAnyway:"\u00BFCambiar la representaci\u00F3n de toles maneres?\n\n(Calque Aceutar pa cambiar, Encaboxar pa siguir cola representaci\u00F3n actual)",ScaleMath:"Ampliar toles f\u00F3rmules (en comparancia col testu d'alredor) nun",NonZeroScale:"La escala nun tien de ser cero",PercentScale:"La escala tien de ser un porcentaxe (por exemplu 120%%)",IE8warning:"Esto desactivar\u00E1 les funciones de men\u00FA y zoom de MathJax, pero pue facer Alt-Clic nuna espresi\u00F3n pa ver el men\u00FA de MathJax.\n\n\u00BFRealmente quier cambiar la configuraci\u00F3n de MathPlayer?",IE9warning:"El men\u00FA contestual de MathJax tar\u00E1 desactiv\u00E1u, pero pue facer Alt-Clic nuna espresi\u00F3n pa ver el men\u00FA MathJax.",NoOriginalForm:"Nun ta disponible denguna forma orixinal",Close:"Zarrar",EqSource:"C\u00F3digu fonte d'ecuaci\u00F3n MathJax",CloseAboutDialog:"Zarrar el di\u00E1logu de tocante a MathJax",FastPreview:"Vista previa r\u00E1pida",AssistiveMML:"Asistencia MathML",InTabOrder:"Incluir nel orde de lling\u00FCetes"}});MathJax.Ajax.loadComplete("[MathJax]/localization/ast/MathMenu.js");
